package info.aspirecn.iov.sjjh.supplier10000034.action;




import javax.servlet.http.HttpServletRequest;
import org.apache.commons.codec.binary.Base64;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000034.SjjhConstants;
import info.aspirecn.iov.sjjh.supplier10000034.service.Supplier10000034Service;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import info.aspirecn.iov.sjjh.supplier10000034.gjwl.util.Properties;

/**
 * 
 * @author bzh
 *
 */
@Slf4j
@RestController
public class Supplier10000034Action {
	/**日志参数中的错误参数名*/
	private static final String LOG_ERROR_PARA = "respnoseCode";
	/**日志参数中的是否收费*/
	private static final String LOG_FEE_PARA = "isCharge";
	@Autowired
	Properties properties;
	@Autowired
	private Supplier10000034Service service;

	Logger logger = LoggerFactory.getLogger("CallbackTimeoutLogUtil");
	
	@ApiOperation(value = "获取企业信息查询接口", notes = "")
	@PostMapping(value = "/queryEnterprise.do")
    public ChannelTypeHandleResponseObject queryEnterprise(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryEnterprise(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000034Action.queryEnterprise.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}

	
	@ApiOperation(value = "获取人员信息查询接口", notes = "")
	@PostMapping(value = "/queryPerson.do")
    public ChannelTypeHandleResponseObject queryPerson(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryPerson(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000034Action.queryPerson.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}


	@ApiOperation(value = "验证车辆运输许可证信息接口", notes = "")
	@PostMapping(value = "/checkVehiclePermit.do")
	public ChannelTypeHandleResponseObject checkVehiclePermit(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkVehiclePermit(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getResultCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.checkVehiclePermit.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}

	@ApiOperation(value = "超载核验", notes = "")
	@PostMapping(value = "/overloadCheck.do")
	public ChannelTypeHandleResponseObject overloadCheck(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.overloadCheck(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getResultCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.overloadCheck.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}

	@ApiOperation(value = "车辆入网核验", notes = "")
	@PostMapping(value = "/checkVehicleExist.do")
	public ChannelTypeHandleResponseObject checkVehicleExist(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkVehicleExist(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getResultCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.queryVehiclePermit.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}

	@ApiOperation(value = "获取企业信息查询接口-数据信用", notes = "")
	@PostMapping(value = "/queryEnterpriseSjxy.do")
	public ChannelTypeHandleResponseObject queryEnterpriseSjxy(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		request.setAttribute(LOG_FEE_PARA,Constant.IS_NOT_CHARGE);
		request.setAttribute(LOG_ERROR_PARA,Constant.CHANNEL_LOG_ERROR_CODE);
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE);

		//调用service
		ChannelTypeHandleResponseObject ret = service.queryEnterpriseSjxy(request, customBody, outTime);

		String ifJkCode = request.getHeader("ifJkCode");


		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			if(Constant.CUSTOMER_RETURN_JK.equals(ifJkCode)){
				String code = properties.getCode().get(ret.getResultCode());
				if(code!=null){
					ret.setResultCode(Integer.valueOf(code));
				}
			}
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());


		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.queryEnterpriseSjxy.Exception{}", ex);
		}

		return ret;
	}


	@ApiOperation(value = "获取人员信息查询接口-数据信用", notes = "")
	@PostMapping(value = "/queryPersonSjxy.do")
	public ChannelTypeHandleResponseObject queryPersonSjxy(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		request.setAttribute(LOG_FEE_PARA,Constant.IS_NOT_CHARGE);
		request.setAttribute(LOG_ERROR_PARA,Constant.CHANNEL_LOG_ERROR_CODE);
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE);
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryPersonSjxy(request, customBody, outTime);
		String ifJkCode = request.getHeader("ifJkCode");


		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			if(Constant.CUSTOMER_RETURN_JK.equals(ifJkCode)){
				String code = properties.getCode().get(ret.getResultCode());
				if(code!=null){
					ret.setResultCode(Integer.valueOf(code));
				}
			}
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.queryPerson.Exception{}", ex);
		}

		return ret;
	}


	@ApiOperation(value = "验证车辆运输许可证信息接口-数据信用", notes = "")
	@PostMapping(value = "/checkVehiclePermitSjxy.do")
	public ChannelTypeHandleResponseObject checkVehiclePermitSjxy(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		request.setAttribute(LOG_FEE_PARA,Constant.IS_NOT_CHARGE);
		request.setAttribute(LOG_ERROR_PARA,Constant.CHANNEL_LOG_ERROR_CODE);
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE);

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkVehiclePermitSjxy(request, customBody, outTime);
		String ifJkCode = request.getHeader("ifJkCode");


		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			if(Constant.CUSTOMER_RETURN_JK.equals(ifJkCode)){
				String code = properties.getCode().get(ret.getResultCode());
				if(code!=null){
					ret.setResultCode(Integer.valueOf(code));
				}
			}
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.checkVehiclePermit.Exception{}", ex);
		}
		return ret;
	}

	@ApiOperation(value = "车辆入网核验-数据信用", notes = "")
	@PostMapping(value = "/checkVehicleExistSjxy.do")
	public ChannelTypeHandleResponseObject checkVehicleExistSjxy(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		request.setAttribute(LOG_FEE_PARA,Constant.IS_NOT_CHARGE);
		request.setAttribute(LOG_ERROR_PARA,Constant.CHANNEL_LOG_ERROR_CODE);
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE);

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkVehicleExistSjxy(request, customBody, outTime);


		//把接口参数、调用结果和是否收费放入访问日志中
		String ifJkCode = request.getHeader("ifJkCode");
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			if(Constant.CUSTOMER_RETURN_JK.equals(ifJkCode)){
				String code = properties.getCode().get(ret.getResultCode());
				if(code!=null){
					ret.setResultCode(Integer.valueOf(code));
				}
			}
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.queryVehiclePermit.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}



}
