package info.aspirecn.iov.sjjh.supplier10000034.action;


import javax.servlet.http.HttpServletRequest;
import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000034.SjjhConstants;
import info.aspirecn.iov.sjjh.supplier10000034.service.Supplier10000034SecondService;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import info.aspirecn.iov.sjjh.supplier10000034.gjwl.util.Properties;

/**
 * 
 * @author bzh
 *
 */
@Slf4j
@RestController
public class Supplier10000034SecondAction {
	/**日志参数中的错误参数名*/
	private static final String LOG_ERROR_PARA = "respnoseCode";
	/**日志参数中的是否收费*/
	private static final String LOG_FEE_PARA = "isCharge";
	@Autowired
	Properties properties;
	@Autowired
	private Supplier10000034SecondService service;

	

	@ApiOperation(value = "企业道路运输经营许可证核查", notes = "")
	@PostMapping(value = "/checkEnterprisePermit.do")
	public ChannelTypeHandleResponseObject checkEnterprisePermit(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkEnterprisePermit(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.checkVehicleRoadTransport.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}


	@ApiOperation(value = "人员从业资格证核查接口", notes = "")
	@PostMapping(value = "/checkPersonQualification.do")
	public ChannelTypeHandleResponseObject checkPersonQualification(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkPersonQualification(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.checkVehicleRoadTransport.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}


	@ApiOperation(value = "核查车辆道路运输证信息", notes = "")
	@PostMapping(value = "/checkVehicleRoadTransport.do")
	public ChannelTypeHandleResponseObject checkVehicleRoadTransport(
			@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
			@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
			@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();

		//调用service
		ChannelTypeHandleResponseObject ret = service.checkVehicleRoadTransport(request, customBody, outTime);

		//把接口参数、调用结果和是否收费放入访问日志中
		if(ret.getCode() != Constant.SUCCESS) {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
		} else {
			request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
		}
		request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY,
					Base64.encodeBase64String(customBody.getBytes(SjjhConstants.PARA_ENCODE)));

		} catch (Exception ex) {
			ErrorUtils.captureException(ex);
			log.error("Supplier10000034Action.checkVehicleRoadTransport.Exception{}", ex);
		}

		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
		return ret;
	}



}
